//
//  Test_v3div.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_v3div_h
#define BulletTest_Test_v3div_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_v3div(void);

#ifdef __cplusplus
}
#endif

#endif
